%
% load_data.m
%
% script to load data from 1) AERI, SHIS, and NAST NetCDF files, 2) HIS 100 word
% header files, and 3) pre-saved MATLAB binary files.
%
% If you choose a NetCDF file, you have the option of reading in all the
% data (includng the radiances) or all of the data except for the radiances.  
% If you chose not to read in the radiances, the rest of the code will
% proceed in the radiance "random-read" mode, where the radiances are read
% in from the file as you need them.  This saves time and memeory for when 
% you're dealing with very large files.  
%
% If you chose a HIS 100 word header file, all of the radiances are read in,
% with no option for the "random read" mode.
%
% If you choose a MATLAB binary file, the program assumes that the file
% all of the data (including the radiances) in the appropriate structure
% variable ("data") with all the required filed names.
%

% clear data structure and netcdf object from the workspace before beginning
clear data fnetcdf

% prompt user for file name and depending on the extesion of the file name,
% decide if its a NetCDf file, 100 word head file, or a binary matlab file.
[fname,pname]=uigetfile('*');
filename = [pname fname];

%
% load it in NetCDF file and assign variables
%
if ~isempty(findstr(fname,'cdf')) | ~isempty(findstr(fname,'CDF')) | ...
   ~isempty(findstr(fname,'nc')) | ~isempty(findstr(fname,'NC')) | ...
   ~isempty(findstr(fname,'cdr')) | ~isempty(findstr(fname,'CDR'))

 disp('--- loading housekeeping data from NetCDF file ---')
 [fnetcdf,data] = rd_housekeep(filename);
 % this returns the netcdf object "fnetcdf" for later access into the
 % file and the data structure "data" without the radiances.

 % get user to input names of essential variables if not defined yet
 
 % wavenumbers
 if isfield(data,'wnum1')
   disp('... essential variable "wnum1" is defined')
 else
   disp(' ')
   disp('... essential variable "wnum1" is not defined')
   disp('... this should be the wavenumber vector')
   disp(' ')
   disp('... the variables in the NetCDF file are: ')
   more on
   ncnames(var(fnetcdf))'
   more off
   tmp = input('Enter the name of the wavenumber vector : ','s');
   eval(['data.wnum1 = data.' tmp ';'])
 end

 % radiances
 if isfield(data,'Rname')
   disp('... essential variable "Rname" is defined')
 else
   disp(' ')
   disp('... essential variable "Rname" is not defined')
   disp('.... this should be the name of the radiance vectors')
   disp(' ')
   disp('... the variables in the NetCDF file are: ')
   more on
   ncnames(var(fnetcdf))'
   more off
   tmp = input('Enter the name of the radiance variable : ','s');
   data.Rname = tmp;
 end

 % scene mirror angles
 
 % use FOVangle if it exists
 if isfield(data,'FOVangle') & ~isfield(data,'sceneMirrorAngle')
   data.sceneMirrorAngle = data.FOVangle;
   disp('... assigning FOVangle to sceneMirrorAngle')
 end

 if isfield(data,'sceneMirrorAngle')
   disp('... essential variable "sceneMirrorAngle" is defined')
 else
   disp(' ')
   disp('... essential variable "sceneMirrorAngle" is not defined')
   disp('... this should be the name of the scene mirror angles')
   disp('... (integers with nadir = 0)')
   disp(' ')
   disp('... The variables in the NetCDF file are: ')
   more on
   ncnames(var(fnetcdf))'
   more off
   tmp = input('Enter the name of the scene mirror angle variable : ','s');
   eval(['data.sceneMirrorAngle = data.' tmp ';'])
 end
   
%
% load in HIS data in .ame or .ume files (including radiances)
%
elseif ~isempty(findstr(lower(fname),'.ume')) | ~isempty(findstr(lower(fname),'.ame'))
 disp('--- loading in 100 word header file ---')
 data = umereader(filename);

% 
% load in MATLAB binary file
%
elseif ~isempty(findstr(fname,'.mat')) | ~isempty(findstr(fname,'.MAT'))
 disp('--- loading in MATLAB binary file ---')
 eval(['load ' filename])
end


if isfield(data,'base_time')
   disp('... essential variable "base_time" is defined')
else
   disp(' ')
   disp('... essential variable "base_time" is not defined')
   disp(' ')
   disp('... The variables in the NetCDF file are: ')
   more on
   ncnames(var(fnetcdf))'
   more off
   tmp = input('Enter the name of the base_time variable : ','s');
   eval(['data.base_time = data.' tmp ';'])
end

if isfield(data,'time_offset')
   disp('... essential variable "time_offset" is defined')
else
   disp(' ')
   disp('... essential variable "time_offset" is not defined')
   disp(' ')
   disp('... The variables in the NetCDF file are: ')
   more on
   ncnames(var(fnetcdf))'
   more off
   tmp = input('Enter the name of the time_offset variable : ','s');
   eval(['data.time_offset = data.' tmp ';'])
end

if isfield(data,'Latitude')
   disp('... essential variable "Latitude" is defined')
else
   disp(' ')
   disp('... essential variable "Latitude" is not defined')
   disp(' ')
   disp('... The variables in the NetCDF file are: ')
   more on
   ncnames(var(fnetcdf))'
   more off
   tmp = input('Enter the name of the Latitude variable : ','s');
   eval(['data.Latitude = data.' tmp ';'])
end

if isfield(data,'Longitude')
   disp('... essential variable "Longitude" is defined')
else
   disp(' ')
   disp('... essential variable "Longitude" is not defined')
   disp(' ')
   disp('... The variables in the NetCDF file are: ')
   more on
   ncnames(var(fnetcdf))'
   more off
   tmp = input('Enter the name of the Longitude variable : ','s');
   eval(['data.Longitude = data.' tmp ';'])
end
  

% assign other fields required by the browser
data.nss1970 = data.base_time + data.time_offset;
data.dateNumber = dn(data.nss1970);
data.fileName = filename;
data.index = (1:1:length(data.time_offset))';

[jnk,jnk,jnk,HH,MM,SS] = datevec(dn(data.nss1970));
data.timeHHMMSS = HH*1e4 + MM*1e2 + SS;
% compute decimal time
hr = floor( data.timeHHMMSS/10000 );
tmp = (data.timeHHMMSS/10000 - hr) * 100;
min = floor(tmp);
sec = ( tmp - min ) * 100;
data.timeDECIMAL = hr + min/60 + sec/3600;
clear hr tmp min sec 

data.nspec = length(data.time_offset);

% try to do intelligent modification of the scene mirror angles 
data.sceneMirrorAngle = round(data.sceneMirrorAngle);
if length(find(data.sceneMirrorAngle == 0))==0 & ...
   length(find(data.sceneMirrorAngle == 180)) > 0
  data.sceneMirrorAngle = data.sceneMirrorAngle - 180;
  disp('... 180 subtracted from scene mirror angles')
end
if length(find(data.sceneMirrorAngle == 0))==0 & ...
   length(find(data.sceneMirrorAngle == -180)) > 0
  data.sceneMirrorAngle = data.sceneMirrorAngle + 180;
  disp('... 180 added to scene mirror angles')
end

clear fname pname filename jnk hr tmp min sec 

disp('--------- done loading data ----------')




